@@ -116,6 +116,16 @@ impl Osu {
         GetBeatmapUserScore::new(self, map_id, user_id)
     }
 
+    /// Get a vec of [`Score`](crate::model::score::Score).
+    ///
+    /// The contained scores won't have any Options filled except
+    /// for `pp` in case of a ranked map.
+    #[cfg(not(feature = "cache"))]
+    #[inline]
+    pub fn beatmap_user_scores(&self, map_id: u32, user_id: u32) -> GetBeatmapUserScores<'_> {
+        GetBeatmapUserScores::new(self, map_id, user_id)
+    }
+
     /// Get a [`BeatmapUserScore`](crate::model::score::BeatmapUserScore).
     ///
     /// The contained [`Score`](crate::model::score::Score) will have the
@@ -130,6 +140,20 @@ impl Osu {
         GetBeatmapUserScore::new(self, map_id, user_id.into())
     }
 
+    /// Get a vec of [`Score`](crate::model::score::Score).
+    ///
+    /// The contained scores won't have any Options filled except
+    /// for `pp` in case of a ranked map.
+    #[cfg(feature = "cache")]
+    #[inline]
+    pub fn beatmap_user_scores(
+        &self,
+        map_id: u32,
+        user_id: impl Into<UserId>,
+    ) -> GetBeatmapUserScores<'_> {
+        GetBeatmapUserScores::new(self, map_id, user_id.into())
+    }
+
     /// Get a [`Beatmapset`](crate::model::beatmap::Beatmapset).
     ///
     /// Filled options will be: `artist_unicode`, `converts`, `description`,
