@@ -4,9 +4,14 @@ use serde::{
 };
 use std::fmt;
 
+#[cfg(feature = "rkyv")]
+use rkyv::{Archive, Deserialize as RkyvDeserialize, Serialize as RkyvSerialize};
+
 /// Available game modes
 #[allow(clippy::upper_case_acronyms)]
 #[derive(Copy, Clone, Debug, Eq, PartialEq, Hash)]
+#[cfg_attr(feature = "rkyv", derive(Archive, RkyvDeserialize, RkyvSerialize), archive(as = "Self"))]
+#[repr(u8)]
 pub enum GameMode {
     /// osu!standard
     STD = 0,
