@@ -615,3 +615,42 @@ mod tests {
         assert_eq!(util::parse_u32("00123"), Some(123));
     }
 }
+
+#[cfg(feature = "rkyv")]
+mod rkyv_impls {
+    use rkyv::{Archive, Archived, Deserialize, Fallible, Resolver, Serialize};
+
+    use super::GameMods;
+
+    const _: () = {
+        impl Archive for GameMods {
+            type Archived = Archived<u32>;
+            type Resolver = Resolver<u32>;
+
+            #[inline]
+            unsafe fn resolve(&self, pos: usize, _: Self::Resolver, out: *mut Self::Archived) {
+                self.bits.resolve(pos, (), out);
+            }
+        }
+    };
+
+    const _: () = {
+        impl<S: Fallible + ?Sized> Serialize<S> for GameMods {
+            #[inline]
+            fn serialize(&self, _: &mut S) -> Result<Self::Resolver, S::Error> {
+                Ok(())
+            }
+        }
+    };
+
+    const _: () = {
+        impl<D: Fallible + ?Sized> Deserialize<GameMods, D> for Archived<GameMods> {
+            #[inline]
+            fn deserialize(&self, d: &mut D) -> Result<GameMods, D::Error> {
+                let bits = Deserialize::<u32, D>::deserialize(self, d)?;
+
+                Ok(GameMods::from_bits_truncate(bits))
+            }
+        }
+    };
+}
