@@ -2,12 +2,13 @@ use crate::{
     model::{
         beatmap::{
             Beatmap, Beatmapset, BeatmapsetEvents, BeatmapsetSearchResult, BeatmapsetSearchSort,
-            Genre, Language, RankStatus, SearchRankStatus,
+            Genre, Language, RankStatus,
         },
-        score::{BeatmapScores, BeatmapUserScore, Score},
+        beatmap_::{Beatmaps, SearchRankStatus},
+        score_::{BeatmapScores, BeatmapUserScore, Score, Scores},
         Cursor, GameMode, GameMods,
     },
-    prelude::{BeatmapCompact, Beatmaps},
+    prelude::BeatmapCompact,
     request::{Pending, Query, Request},
     routing::Route,
     Osu,
@@ -364,6 +365,104 @@ impl<'a> GetBeatmapUserScore<'a> {
 
 poll_req!(GetBeatmapUserScore => BeatmapUserScore);
 
+/// Get the top score with each mod combination of a user on
+/// a map in the form of a vec of [`Score`]s.
+#[must_use = "futures do nothing unless you `.await` or poll them"]
+pub struct GetBeatmapUserScores<'a> {
+    fut: Option<Pending<'a, Vec<Score>>>,
+    osu: &'a Osu,
+    map_id: u32,
+    mode: Option<GameMode>,
+
+    #[cfg(not(feature = "cache"))]
+    user_id: u32,
+
+    #[cfg(feature = "cache")]
+    user_id: Option<UserId>,
+}
+
+impl<'a> GetBeatmapUserScores<'a> {
+    #[cfg(not(feature = "cache"))]
+    #[inline]
+    pub(crate) fn new(osu: &'a Osu, map_id: u32, user_id: u32) -> Self {
+        Self {
+            fut: None,
+            osu,
+            map_id,
+            user_id,
+            mode: None,
+        }
+    }
+
+    #[cfg(feature = "cache")]
+    #[inline]
+    pub(crate) fn new(osu: &'a Osu, map_id: u32, user_id: UserId) -> Self {
+        Self {
+            fut: None,
+            osu,
+            map_id,
+            user_id: Some(user_id),
+            mode: None,
+        }
+    }
+
+    /// Specify the mode
+    #[inline]
+    pub fn mode(mut self, mode: GameMode) -> Self {
+        self.mode.replace(mode);
+
+        self
+    }
+
+    fn start(&mut self) -> Pending<'a, Vec<Score>> {
+        #[cfg(feature = "metrics")]
+        self.osu.metrics.beatmap_user_score.inc();
+
+        let mut query = Query::new();
+
+        if let Some(mode) = self.mode {
+            query.push("mode", &mode.to_string());
+        }
+
+        #[cfg(not(feature = "cache"))]
+        {
+            let route = Route::GetBeatmapUserScores {
+                user_id: self.user_id,
+                map_id: self.map_id,
+            };
+
+            let req = Request::with_query(route, query);
+
+            let fut = self
+                .osu
+                .inner
+                .request::<Scores>(req)
+                .map_ok(|scores| scores.scores);
+
+            Box::pin(fut)
+        }
+
+        #[cfg(feature = "cache")]
+        {
+            let map_id = self.map_id;
+            let osu = &self.osu.inner;
+
+            let fut = self
+                .osu
+                .cache_user(self.user_id.take().unwrap())
+                .map_ok(move |user_id| {
+                    Request::with_query(Route::GetBeatmapUserScores { user_id, map_id }, query)
+                })
+                .and_then(move |req| osu.request::<Scores>(req))
+                .map_ok(|scores| scores.scores);
+
+            Box::pin(fut)
+        }
+    }
+}
+
+poll_req!(GetBeatmapUserScores => Vec<Score>);
+
 /// Get a [`Beatmapset`](crate::model::beatmap::Beatmapset).
 #[must_use = "futures do nothing unless you `.await` or poll them"]
 pub struct GetBeatmapset<'a> {
