@@ -2,10 +2,10 @@ use crate::{
     error::OsuError,
     model::{
         beatmap::{Beatmapset, MostPlayedMap, RankStatus},
-        kudosu::KudosuHistory,
-        recent_event::RecentEvent,
-        score::Score,
-        user::{User, UserCompact},
+        kudosu_::KudosuHistory,
+        recent_event_::RecentEvent,
+        score_::Score,
+        user_::{User, UserCompact},
         GameMode,
     },
     prelude::Username,
